"""
    testsmanager.gitlab
    Wrapper for the GitLab API

    Copyright (c) 2015 Pietro Albini <pietroalbini@ubuntu.com>
    Released under the GNU-AGPL v3 license
"""

import requests


class GitLabAPI:
    """Wrapper for the GitLab API"""

    def __init__(self, manager):
        self.manager = manager
        self.url = manager.config["gitlab-url"]
        self.token = manager.config["gitlab-token"]
        self.project = manager.config["gitlab-project"]

    def call(self, method, endpoint, params=None, data=None):
        """Make a raw call to the GitLab API"""
        if params == None:
            params = {}
        if data is None:
            data = {}

        url = self.url+"/api/v3/"+endpoint
        params["private_token"] = self.token

        response = requests.request(method, url, params=params, data=data)
        if response.status_code == 200:
            return response.json()
        return False

    def merge_requests(self):
        """Get all the merge requests of the project"""
        return self.call("get", "projects/%s/merge_requests" % self.project, {
            "state": "opened",
        })

    def merge_request(self, id):
        """Get a single merge request on the project"""
        return self.call("get", "projects/%s/merge_request/%s" % (
            self.project, id))

    def post_comment(self, id, text):
        """Post a comment on a merge request"""
        return self.call("post", "projects/%s/merge_request/%s/comments" % (
            self.project, id), args={"note": text})
