import queue
import threading

import flask


class HooksProcessor(threading.Thread):
    """A class which processes hooks"""

    def __init__(self, manager):
        self.manager = manager
        self.q = queue.Queue()
        self.stop = False

        super(HooksProcessor, self).__init__()

    def append(self, data):
        """Append something to the queue"""
        self.q.put(data)

    def run(self):
        """Run the thread"""
        while not self.stop:
            try:
                data = self.q.get(timeout=0.2)
            except queue.Empty:
                continue

            self.manager.process_hook(data)


def create_app(manager, processor):
    """Create an instance of the app which captures webhooks"""
    app = flask.Flask(__name__)

    @app.route("/+hook", methods=["POST"])
    def hook():
        processor.append(flask.request.data)
        return "OK"

    return app
